from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_check import BaseResourceCheck


class AzureInstancePassword(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Azure Instance does not use basic authentication(Use SSH Key Instead)"
        id = "CKV_AZURE_1"
        supported_resources = ['Microsoft.Compute/virtualMachines']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        properties = conf.get("properties")
        if isinstance(properties, dict):
            storage_profile = properties.get("storageProfile")
            if isinstance(storage_profile, dict):
                image_reference = storage_profile.get("imageReference")
                if isinstance(image_reference, dict):
                    publisher = image_reference.get("publisher")
                    if publisher and "windows" in publisher.lower():
                        # This check is not relevant to Windows systems
                        return CheckResult.PASSED

            os_profile = properties.get("osProfile")
            if isinstance(os_profile, dict):
                linux_conf = os_profile.get("linuxConfiguration")
                if isinstance(linux_conf, dict) and linux_conf.get("disablePasswordAuthentication"):
                    return CheckResult.PASSED
        return CheckResult.FAILED

check = AzureInstancePassword()




from checkov.common.models.enums import CheckCategories,CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from typing import Dict, List, Any
from checkov.common.util.type_forcers import force_list


class FirewallIngressOpen(BaseResourceCheck):
    def __init__(self):
        name = "Ensure the firewall ingress is not wide open"
        id = "CKV_DIO_4"
        supported_resources = ['digitalocean_firewall']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        if 'inbound_rule' in conf.keys():
            ingress_conf = conf['inbound_rule']
            for ingress_rule in ingress_conf:
                ingress_rules = force_list(ingress_rule)
                for rule in ingress_rules:
                    if rule['source_addresses']:
                        sources = rule["source_addresses"][0]
                        if any(item in ["0.0.0.0/0", "::/0"] for item in sources):
                           self.evaluated_keys=["inbound_rule/[0]/source_addresses"]
                           return CheckResult.FAILED
            return CheckResult.PASSED
        return CheckResult.PASSED


check = FirewallIngressOpen()
